diff src/glyphs-x.c @ 50:ee648375d8d6 r19-16b91

Import from CVS: tag r19-16b91
author cvs
date Mon, 13 Aug 2007 08:56:41 +0200
parents 56c54cf7c5b6
children c0965ff3b039
line wrap: on
line diff
--- a/src/glyphs-x.c	Mon Aug 13 08:56:06 2007 +0200
+++ b/src/glyphs-x.c	Mon Aug 13 08:56:41 2007 +0200
@@ -3586,8 +3586,8 @@
  which are both being displayed simultaneously you will lose big time.
  This can be dealt with in the new redisplay. */
 
-/* #### These are completely un-re-implemented in 19.14.  Get it done
-   for 19.15. */
+/* #### These are completely un-re-implemented in 19.16.  Get it done
+   for 20.3. */
 
 DEFUN ("make-subwindow", Fmake_subwindow, 0, 3, 0, /*
 Creates a new `subwindow' object of size WIDTH x HEIGHT.
@@ -3611,7 +3611,7 @@
   XSetWindowAttributes xswa;
   Mask valueMask = 0;
 
-  error ("subwindows are not functional in 19.14; they will be in 19.15");
+  error ("subwindows are not functional in 19.16; perhaps some day ...");
 
   f = decode_x_frame (frame);